@@ -42,10 +42,6 @@
 #include "thpdf.h"
 #include "thtexfonts.h"
 #include <string.h>
-#ifdef THMSVC
-#include <direct.h>
-#define getcwd _getcwd
-#endif
 
 
 thlookup::thlookup()
@@ -126,6 +122,7 @@ void thlookup::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
     case TT_DATAOBJECT_AUTHOR:
     case TT_DATAOBJECT_COPYRIGHT:
       defcod.nargs = 2;
+      [[fallthrough]];
     default:
       if (cod.nargs > defcod.nargs)
         ththrow("too many arguments -- {}", args[defcod.nargs]);
@@ -155,6 +152,7 @@ void thlookup::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
       tmpb = lkpnname;
       tmpa[0] = tmpb.get_buffer();
       args = tmpa;
+      [[fallthrough]];
     default:
       thdataobject::set(cod, args, argenc, indataline);
       break;
