@@ -71,6 +71,9 @@
 
 ///////////
 
+const int prec_matrix = 6;
+const int prec_xy = 2;
+
 typedef struct {
   int id;
   int namex,namey,layer;
@@ -350,7 +353,7 @@ void find_jumps() {
 
 int grid_str2int(std::string s, char init = 'A') {
   int res = 0;
-  for (int i = 0; i < s.length(); i++) res = 26*res + s[i] - init + 1;
+  for (size_t i = 0; i < s.length(); i++) res = 26*res + s[i] - init + 1;
   return res;
 }
 
@@ -447,9 +450,9 @@ void sort_sheets() {
             pageid++;
           }
           else {
-            SHEET.erase(sheet_it);
             SHEET_JMP.erase(xyz2str(sheet_it->layer,
                                     sheet_it->namex,sheet_it->namey));
+            SHEET.erase(sheet_it);
 //cout << "Should erase sheet " << tmppagenum << std::endl;
           }
           tmppagenum++;
@@ -473,7 +476,7 @@ void print_preview(int up,std::ofstream& PAGEDEF,double HSHIFT,double VSHIFT,
     if (mode == MAP)
       PAGEDEF << "\\setbox\\xxx=\\hbox to \\adjustedHS{%" << std::endl;
     else 
-      PAGEDEF << "\\setbox\\xxx=\\hbox to " << HS << "bp{%" << std::endl;
+      PAGEDEF << "\\setbox\\xxx=\\hbox to " << fmt::format("{}",thdouble(HS,prec_xy)) << "bp{%" << std::endl;
   }
 
 //  PAGEDEF << (up ? "\\PL{q .1 w}%" : "\\PL{q .8 g}%") << std::endl;
@@ -514,7 +517,7 @@ void print_preview(int up,std::ofstream& PAGEDEF,double HSHIFT,double VSHIFT,
               xc = K->B1; yc = K->B2;
               xc -= HSHIFT; yc -= VSHIFT;
               PAGEDEF << (mode == MAP && LAYOUT.OCG ? "\\PBcorr{" : "\\PB{") << 
-                      xc << "}{" << yc << "}{" <<
+                      fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                       tex_get_ref(tex_Xname("B"+(K->name))) << "}%" << std::endl;
             }
           }
@@ -523,7 +526,7 @@ void print_preview(int up,std::ofstream& PAGEDEF,double HSHIFT,double VSHIFT,
               xc = K->I1; yc = K->I2;
               xc -= HSHIFT; yc -= VSHIFT;
               PAGEDEF << (mode == MAP && LAYOUT.OCG ? "\\PBcorr{" : "\\PB{") << 
-                      xc << "}{" << yc << "}{" <<
+                      fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                       tex_get_ref(tex_Xname("I"+(K->name))) << "}%" << std::endl;
             }
           }
@@ -536,7 +539,7 @@ void print_preview(int up,std::ofstream& PAGEDEF,double HSHIFT,double VSHIFT,
     if (mode==MAP)
       PAGEDEF << "\\hfill}\\ht\\xxx=\\adjustedVS\\dp\\xxx=0bp" << std::endl;
     else 
-      PAGEDEF << "\\hfill}\\ht\\xxx=" << VS << "bp\\dp\\xxx=0bp" << std::endl;
+      PAGEDEF << "\\hfill}\\ht\\xxx=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp\\dp\\xxx=0bp" << std::endl;
     PAGEDEF << "\\immediate\\pdfxform ";
     PAGEDEF << "attr{/OC \\the\\" << (up ? "ocU" : "ocD") << "\\space 0 R} ";
     if (icc_used())  PAGEDEF << "resources{/ColorSpace <<" << icc2pdfresources() << ">>} ";
@@ -566,9 +569,9 @@ void compose_page(std::list<sheetrecord>::iterator sheet_it, std::ofstream& PAGE
                   "} count 0 {\\ne\\376\\ne\\377" << 
                   utf2texoctal(lay_it->second.N) << "}%" << std::endl;
   }
-  PAGE.precision(6);
-  PAGE << "\\setbox\\mapbox=\\hbox to " << HS << "bp{%" << std::endl;
-  PAGE.precision(2);
+  //PAGE.precision(6);
+  PAGE << "\\setbox\\mapbox=\\hbox to " << fmt::format("{}",thdouble(HS,prec_matrix)) << "bp{%" << std::endl;
+  //PAGE.precision(2);
   PAGE << "\\rlap{\\pdfrefxform\\" << tex_Sname(u2str(sheet_it->id)) << 
           "}%" << std::endl;
 
@@ -577,18 +580,18 @@ void compose_page(std::list<sheetrecord>::iterator sheet_it, std::ofstream& PAGE
   double lhy = VS - 2*lw;
   double lhx = HS - 2*lw;
   if (sheet_it->jumpW) PAGE << "\\flatlink{0}{" << lw << "}{" << lw << 
-          "}{" << lhy << "}{" << u2str(sheet_it->jumpW) << "}%\n";
+          "}{" << fmt::format("{}",thdouble(lhy,prec_xy)) << "}{" << u2str(sheet_it->jumpW) << "}%\n";
   if (sheet_it->jumpE) PAGE << "\\flatlink{" << HS-lw << "}{" << lw <<
-          "}{" << lw << "}{" << lhy << "}{" << u2str(sheet_it->jumpE) << "}%\n";
-  if (sheet_it->jumpN) PAGE << "\\flatlink{" << lw << "}{" << VS-lw << 
-          "}{" << lhx << "}{" << lw << "}{" << u2str(sheet_it->jumpN)<< "}%\n";
-  if (sheet_it->jumpS) PAGE << "\\flatlink{" << lw << "}{0}{" << lhx << 
+          "}{" << lw << "}{" << fmt::format("{}",thdouble(lhy,prec_xy)) << "}{" << u2str(sheet_it->jumpE) << "}%\n";
+  if (sheet_it->jumpN) PAGE << "\\flatlink{" << lw << "}{" << fmt::format("{}",thdouble(VS-lw,prec_xy)) <<
+          "}{" << fmt::format("{}",thdouble(lhx,prec_xy)) << "}{" << lw << "}{" << u2str(sheet_it->jumpN)<< "}%\n";
+  if (sheet_it->jumpS) PAGE << "\\flatlink{" << lw << "}{0}{" << fmt::format("{}",thdouble(lhx,prec_xy)) <<
           "}{" << lw << "}{" << u2str(sheet_it->jumpS) << "}%\n";
   
 
-  PAGE.precision(6);
-  PAGE << "\\hfil}\\ht\\mapbox=" << VS << "bp%" << std::endl;
-  PAGE.precision(2);
+  //PAGE.precision(6);
+  PAGE << "\\hfil}\\ht\\mapbox=" << fmt::format("{}",thdouble(VS,prec_matrix)) << "bp%" << std::endl;
+  //PAGE.precision(2);
 
   PAGE << "\\pagelabel={" << grid_name(LAYOUT.labely,-sheet_it->namey) << 
                         " " << grid_name(LAYOUT.labelx,sheet_it->namex) <<
@@ -652,9 +655,9 @@ void compose_page(std::list<sheetrecord>::iterator sheet_it, std::ofstream& PAGE
         std::string tmp = xyz2str(sheet_it->layer,
                              sheet_it->namex+i,sheet_it->namey+j);
         if (SHEET_JMP.count(tmp) > 0) {
-          PAGE << "\\flatlink{" << HSN*(i+LAYOUT.nav_right)/nav_x <<
-            "}{" << VSN*(j+LAYOUT.nav_up)/nav_y << "}{" <<
-            HSN/nav_x << "}{" << VSN/nav_y << "}{" << 
+          PAGE << "\\flatlink{" << fmt::format("{}",thdouble(HSN*(i+LAYOUT.nav_right)/nav_x,prec_xy)) <<
+            "}{" << fmt::format("{}",thdouble(VSN*(j+LAYOUT.nav_up)/nav_y,prec_xy)) << "}{" <<
+            fmt::format("{}",thdouble(HSN/nav_x,prec_xy)) << "}{" << fmt::format("{}",thdouble(VSN/nav_y,prec_xy)) << "}{" <<
             u2str(SHEET_JMP.find(tmp)->second->id) << "}%\n";
         }
       }
@@ -671,7 +674,7 @@ void print_page_bg(std::ofstream& PAGEDEF) {
 
     // bg rectangle
     PAGEDEF << "\\PL{q " << LAYOUT.col_background.to_pdfliteral(fillstroke::fill) <<
-                     " 0 0 " << HS << " " << VS << " re f Q}%" << std::endl;
+                     " 0 0 " << fmt::format("{}",thdouble(HS,prec_xy)) << " " << fmt::format("{}",thdouble(VS,prec_xy)) << " re f Q}%" << std::endl;
   }
 }
 
@@ -712,7 +715,7 @@ void print_page_bg_scraps(int layer, std::ofstream& PAGEDEF,
         if (used_scraps.count(K->name) > 0 && K->I != "") {
           xc = K->I1; yc = K->I2;
           xc -= HSHIFT; yc -= VSHIFT;
-          PAGEDEF << "\\PB{" << xc << "}{" << yc << "}{" <<
+          PAGEDEF << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                   tex_get_ref(tex_Xname("I"+(K->name))) << "}%" << std::endl;
         }
       }
@@ -726,11 +729,11 @@ void print_surface_bitmaps (std::ofstream &PAGEDEF, double shiftx, double shifty
     if (mode == MAP)
       PAGEDEF << "\\setbox\\xxx=\\hbox to\\adjustedHS{%" << std::endl;
     else
-      PAGEDEF << "\\setbox\\xxx=\\hbox to" << HS << "bp{%" << std::endl;
+      PAGEDEF << "\\setbox\\xxx=\\hbox to" << fmt::format("{}",thdouble(HS,prec_xy)) << "bp{%" << std::endl;
     PAGEDEF << "\\PL{/GS2 gs}%" << std::endl;
   }
   int i = 1;
-  PAGEDEF.precision(6);
+  //PAGEDEF.precision(6);
   for (std::list<surfpictrecord>::iterator I = SURFPICTLIST.begin();
                                       I != SURFPICTLIST.end(); I++) {
     if (mode == MAP && (LAYOUT.transparency || LAYOUT.OCG)) {
@@ -739,17 +742,18 @@ void print_surface_bitmaps (std::ofstream &PAGEDEF, double shiftx, double shifty
       PAGEDEF << "\\bitmap{";
     }
     PAGEDEF << 
-          I->xx << "}{" << I->yx << "}{" << I->xy << "}{" << I->yy << "}{" << 
-          I->dx - shiftx << "}{" << I->dy - shifty << 
+          fmt::format("{}",thdouble(I->xx,prec_matrix)) << "}{" << fmt::format("{}",thdouble(I->yx,prec_matrix)) << "}{" <<
+          fmt::format("{}",thdouble(I->xy,prec_matrix)) << "}{" << fmt::format("{}",thdouble(I->yy,prec_matrix)) << "}{" <<
+          fmt::format("{}",thdouble(I->dx - shiftx,prec_matrix)) << "}{" << fmt::format("{}",thdouble(I->dy - shifty,prec_matrix)) <<
           "}{\\" << tex_BMPname(u2str(i)) << "}%" << std::endl;
     i++;
   };
-  PAGEDEF.precision(2);
+  //PAGEDEF.precision(2);
   if (LAYOUT.transparency || LAYOUT.OCG) {
     if (mode == MAP)
       PAGEDEF << "\\hfill}\\ht\\xxx=\\adjustedVS\\dp\\xxx=0bp" << std::endl;
     else
-      PAGEDEF << "\\hfill}\\ht\\xxx="<< VS << "bp\\dp\\xxx=0bp" << std::endl;
+      PAGEDEF << "\\hfill}\\ht\\xxx="<< fmt::format("{}",thdouble(VS,prec_xy)) << "bp\\dp\\xxx=0bp" << std::endl;
     PAGEDEF << "\\immediate\\pdfxform ";
     PAGEDEF << "attr{";
     if (LAYOUT.transparency) PAGEDEF << "/Group \\the\\attrid\\space 0 R ";
@@ -859,7 +863,9 @@ PAGEDEF << "\\PL{ " << rotatedaround(urnew,origin,LAYOUT.gridrot).x-LLX << " " <
         out.x -= LLX;
         out.y -= LLY;
         PAGEDEF << "\\PL{q}";
-	PAGEDEF << "\\PL{" << cosr << " " << sinr << " " << -sinr << " " << cosr << " " << out.x << " " << out.y << " cm}";
+	PAGEDEF << "\\PL{" << fmt::format("{}",thdouble(cosr,prec_matrix)) << " " << fmt::format("{}",thdouble(sinr,prec_matrix)) << " "
+                           << fmt::format("{}",thdouble(-sinr,prec_matrix)) << " " << fmt::format("{}",thdouble(cosr,prec_matrix)) << " "
+                           << fmt::format("{}",thdouble(out.x,prec_matrix)) << " " << fmt::format("{}",thdouble(out.y,prec_matrix)) << " cm}";
 	PAGEDEF << "\\PB{0}{0}{" << tex_get_ref(tex_Wname("grid") + u2str(elem+1)) << "}";
         PAGEDEF << "\\PL{Q}%" << std::endl;
 
@@ -870,11 +876,13 @@ PAGEDEF << "\\PL{ " << rotatedaround(urnew,origin,LAYOUT.gridrot).x-LLX << " " <
           out.x -= LLX;
           out.y -= LLY;
           PAGEDEF << "\\PL{q}";
-          PAGEDEF << "\\PL{" << cosr << " " << sinr << " " << -sinr << " " << cosr << " " << out.x << " " << out.y << " cm}";
+          PAGEDEF << "\\PL{" << fmt::format("{}",thdouble(cosr,prec_matrix)) << " " << fmt::format("{}",thdouble(sinr,prec_matrix)) << " "
+                             << fmt::format("{}",thdouble(-sinr,prec_matrix)) << " " << fmt::format("{}",thdouble(cosr,prec_matrix)) << " "
+                             << fmt::format("{}",thdouble(out.x,prec_matrix)) << " " << fmt::format("{}",thdouble(out.y,prec_matrix)) << " cm}";
 	  PAGEDEF << "\\gridcoord{" << (row == 2 ? (col == 2 ? 1 : 3) : (col == 2 ? 7 : 9)) << 
 	      "}{$(" << std::setprecision(0) << 
-	      G_real_init_x+ii*LAYOUT.XS << "," << 
-              G_real_init_y+jj*LAYOUT.YS << std::setprecision(2) << ")$}%" << std::endl;
+	      fmt::format("{}",thdouble(G_real_init_x+ii*LAYOUT.XS,0)) << "," <<
+              fmt::format("{}",thdouble(G_real_init_y+jj*LAYOUT.YS,0)) << std::setprecision(2) << ")$}%" << std::endl;
           PAGEDEF << "\\PL{Q}";
         }
 
@@ -891,23 +899,23 @@ PAGEDEF << "\\PL{ " << rotatedaround(urnew,origin,LAYOUT.gridrot).x-LLX << " " <
         col = (i == grid_init_x ? 0 : (i >= urnew.x ? 2 : 1));
         row = (j == grid_init_y ? 0 : (j >= urnew.y ? 2 : 1));
 	elem = col + 3*row;
-	PAGEDEF << "\\PB{" << i-LLX+LAYOUT.gridcell[elem].x << "}{" << 
-			      j-LLY+LAYOUT.gridcell[elem].y << "}{" <<
+	PAGEDEF << "\\PB{" << fmt::format("{}",thdouble(i-LLX+LAYOUT.gridcell[elem].x,prec_xy)) << "}{" <<
+			      fmt::format("{}",thdouble(j-LLY+LAYOUT.gridcell[elem].y,prec_xy)) << "}{" <<
 			      tex_get_ref(tex_Wname("grid") + u2str(elem+1)) << "}%" << std::endl;
 
         if (col == 0 && LAYOUT.grid_coord_freq > 0) {
           PAGEDEF << "\\PL{q}";
-          PAGEDEF << "\\PL{1 0 0 1 " << i-LLX << " " << j-LLY << " cm}";
+          PAGEDEF << "\\PL{1 0 0 1 " << fmt::format("{}",thdouble(i-LLX,prec_xy)) << " " << fmt::format("{}",thdouble(j-LLY,prec_xy)) << " cm}";
           PAGEDEF << "\\gridcoord{" << (row==2?3:9) << "}{$" << 
-	      std::setprecision(0) << G_real_init_y+jj*LAYOUT.YS << 
+	      std::setprecision(0) << fmt::format("{}",thdouble(G_real_init_y+jj*LAYOUT.YS,0)) <<
 	      std::setprecision(2)<< "$}";
           PAGEDEF << "\\PL{Q}%" << std::endl;
 	}
         if (col == 2 && LAYOUT.grid_coord_freq == 2) {
           PAGEDEF << "\\PL{q}";
-          PAGEDEF << "\\PL{1 0 0 1 " << i-LLX << " " << j-LLY << " cm}";
+          PAGEDEF << "\\PL{1 0 0 1 " << fmt::format("{}",thdouble(i-LLX,prec_xy)) << " " << fmt::format("{}",thdouble(j-LLY,prec_xy)) << " cm}";
           PAGEDEF << "\\gridcoord{" << (row==2?1:7) << "}{$" << 
-	      std::setprecision(0) << G_real_init_y+jj*LAYOUT.YS <<
+	      std::setprecision(0) << fmt::format("{}",thdouble(G_real_init_y+jj*LAYOUT.YS,0)) <<
 	      std::setprecision(2)<< "$}";
           PAGEDEF << "\\PL{Q}%" << std::endl;
         }
@@ -965,7 +973,7 @@ void print_map(int layer, std::ofstream& PAGEDEF,
     used_scraps = (*I).second;
 
     if (LAYOUT.transparency) {                 // transparency group beginning
-      PAGEDEF << "\\setbox\\xxx=\\hbox to " << HS << "bp{%" << std::endl;
+      PAGEDEF << "\\setbox\\xxx=\\hbox to " << fmt::format("{}",thdouble(HS,prec_xy)) << "bp{%" << std::endl;
       PAGEDEF << "\\PL{/GS1 gs}%" << std::endl;     // beginning of transparency
     }
 
@@ -973,33 +981,34 @@ void print_map(int layer, std::ofstream& PAGEDEF,
       if (used_scraps.count(K->name) > 0 && K->I != "") {
         xc = K->I1; yc = K->I2;
         xc -= HSHIFT; yc -= VSHIFT;
-        PAGEDEF << "\\PB{" << xc << "}{" << yc << "}{" <<
+        PAGEDEF << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                 tex_get_ref(tex_Xname("I"+(K->name)+"COLORED")) << "}%" << std::endl;
       }
     }   // end of the colored background
 
     // sketches
-    PAGEDEF.precision(6);
+    //PAGEDEF.precision(6);
     for (std::list<scraprecord>::iterator K = SCRAPLIST.begin(); K != SCRAPLIST.end(); K++) {
       if (used_scraps.count(K->name) > 0) {
         for (std::list<surfpictrecord>::iterator I_sk = K->SKETCHLIST.begin();
                                             I_sk != K->SKETCHLIST.end(); I_sk++) {
           PAGEDEF << "\\pdfximage{" << (std::string) I_sk->filename << "}%" << std::endl;
           PAGEDEF << "\\bitmap{" <<
-              I_sk->xx << "}{" << I_sk->yx << "}{" << I_sk->xy << "}{" << I_sk->yy << "}{" << 
-              I_sk->dx - HSHIFT << "}{" << I_sk->dy - VSHIFT  << 
+              fmt::format("{}",thdouble(I_sk->xx,prec_matrix)) << "}{" << fmt::format("{}",thdouble(I_sk->yx,prec_matrix)) << "}{" <<
+              fmt::format("{}",thdouble(I_sk->xy,prec_matrix)) << "}{" << fmt::format("{}",thdouble(I_sk->yy,prec_matrix)) << "}{" <<
+              fmt::format("{}",thdouble(I_sk->dx - HSHIFT,prec_matrix)) << "}{" << fmt::format("{}",thdouble(I_sk->dy - VSHIFT,prec_matrix))  <<
               "}{\\pdflastximage}%" << std::endl;
         };
       };
     }
-    PAGEDEF.precision(2);
+    //PAGEDEF.precision(2);
     // end of sketches
 
     for (std::list<scraprecord>::iterator K = SCRAPLIST.begin(); K != SCRAPLIST.end(); K++) {
       if (used_scraps.count(K->name) > 0 && K->G != "") {
         xc = K->G1; yc = K->G2;
         xc -= HSHIFT; yc -= VSHIFT;
-        PAGEDEF << "\\PB{" << xc << "}{" << yc << "}{" <<
+        PAGEDEF << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                 tex_get_ref(tex_Xname("G"+(K->name))) << "}%" << std::endl;
       };
     }
@@ -1007,12 +1016,12 @@ void print_map(int layer, std::ofstream& PAGEDEF,
     if (LAYOUT.transparency) {
       PAGEDEF << "\\PL{/GS0 gs}%" << std::endl;      // end of default transparency
       if (LAYOUT.smooth_shading == shading_mode::quick) {
-        PAGEDEF << "\\setbox\\xxx=\\hbox to " << HS << "bp{%\n";  // add another knockout group
+        PAGEDEF << "\\setbox\\xxx=\\hbox to " << fmt::format("{}",thdouble(HS,prec_xy)) << "bp{%\n";  // add another knockout group
       }
     }
 
-    PAGEDEF << "\\PL{q 0 0 m " << HS << " 0 l " << HS << " " << 
-                                  VS << " l 0 " << VS << " l 0 0 l}";
+    PAGEDEF << "\\PL{q 0 0 m " << fmt::format("{}",thdouble(HS,prec_xy)) << " 0 l " << fmt::format("{}",thdouble(HS,prec_xy)) << " " <<
+                                  fmt::format("{}",thdouble(VS,prec_xy)) << " l 0 " << fmt::format("{}",thdouble(VS,prec_xy)) << " l 0 0 l}";
                                // beginning of the text clipping path definition
 
     for (std::list<scraprecord>::iterator K = SCRAPLIST.begin(); K != SCRAPLIST.end(); K++) {
@@ -1025,8 +1034,8 @@ void print_map(int layer, std::ofstream& PAGEDEF,
           if ((buffer == "m") || (buffer == "l") || (buffer == "c")) {
             PAGEDEF << "\\PL{"; 
             for(unsigned i=0; i<thstack.size(); i=i+2) {
-              PAGEDEF << atof(thstack[i].c_str())-xc << " " << 
-                         atof(thstack[i+1].c_str())-yc << " ";
+              PAGEDEF << fmt::format("{}", thdouble(std::stod(thstack[i])-xc,prec_xy)) << " " <<
+                         fmt::format("{}", thdouble(std::stod(thstack[i+1])-yc,prec_xy)) << " ";
             }
             PAGEDEF << buffer << "}%" << std::endl;
             thstack.clear();
@@ -1046,7 +1055,7 @@ void print_map(int layer, std::ofstream& PAGEDEF,
       if (used_scraps.count(K->name) > 0 && K->F != "") {
         xc = K->F1; yc = K->F2;
         xc -= HSHIFT; yc -= VSHIFT;
-        PAGEDEF << "\\PB{" << xc << "}{" << yc << "}{" <<
+        PAGEDEF << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                 tex_get_ref(tex_Xname(K->name)) << "}%" << std::endl;
       };
     }
@@ -1055,7 +1064,7 @@ void print_map(int layer, std::ofstream& PAGEDEF,
       if (used_scraps.count(K->name) > 0 && K->E != "") {
         xc = K->E1; yc = K->E2;
         xc -= HSHIFT; yc -= VSHIFT;
-        PAGEDEF << "\\PB{" << xc << "}{" << yc << "}{" <<
+        PAGEDEF << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                 tex_get_ref(tex_Xname("E"+(K->name))) << "}%" << std::endl;
       };
     }
@@ -1066,13 +1075,13 @@ void print_map(int layer, std::ofstream& PAGEDEF,
       if (used_scraps.count(K->name) > 0 && K->X != "") {
         xc = K->X1; yc = K->X2;
         xc -= HSHIFT; yc -= VSHIFT;
-        PAGEDEF << "\\PB{" << xc << "}{" << yc << "}{" <<
+        PAGEDEF << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                 tex_get_ref(tex_Xname("X"+(K->name))) << "}%" << std::endl;
       };
     }
     if (LAYOUT.transparency) {
       if (LAYOUT.smooth_shading == shading_mode::quick) {
-        PAGEDEF << "\\hfill}\\ht\\xxx=" << VS << "bp\\dp\\xxx=0bp" << std::endl;
+        PAGEDEF << "\\hfill}\\ht\\xxx=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp\\dp\\xxx=0bp" << std::endl;
         PAGEDEF << "\\immediate\\pdfxform ";
         PAGEDEF << "attr{/Group \\the\\attrid\\space 0 R} ";
         PAGEDEF << "resources{/ExtGState \\the\\resid\\space 0 R";
@@ -1080,7 +1089,7 @@ void print_map(int layer, std::ofstream& PAGEDEF,
         PAGEDEF << "}";
         PAGEDEF << "\\xxx\\PB{0}{0}{\\pdflastxform}%" << std::endl;
       }
-      PAGEDEF << "\\hfill}\\ht\\xxx=" << VS << "bp\\dp\\xxx=0bp" << std::endl;
+      PAGEDEF << "\\hfill}\\ht\\xxx=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp\\dp\\xxx=0bp" << std::endl;
       PAGEDEF << "\\immediate\\pdfxform ";
       // the external group can't be a knockout group in the quick mode
       if (LAYOUT.smooth_shading != shading_mode::quick) PAGEDEF << "attr{/Group \\the\\attrid\\space 0 R} ";
@@ -1111,10 +1120,11 @@ void print_navigator(std::ofstream& P, std::list<sheetrecord>::iterator sheet_it
   double VSN = LAYOUT.vsize / LAYOUT.nav_factor * nav_y;
   double xc = 0, yc = 0;
 
-  P << "%\n\\setbox\\xxx=\\hbox to " << HSN << "bp{%\n\\PL{q ";
-  P.precision(6);
-  P << 1/LAYOUT.nav_factor << " 0 0 " << 1/LAYOUT.nav_factor << " 0 0 cm}%\n";
-  P.precision(2);
+  P << "%\n\\setbox\\xxx=\\hbox to " << fmt::format("{}",thdouble(HSN,prec_xy)) << "bp{%\n\\PL{q ";
+  //P.precision(6);
+  P << fmt::format("{}",thdouble(1/LAYOUT.nav_factor,prec_matrix)) << " 0 0 " <<
+       fmt::format("{}",thdouble(1/LAYOUT.nav_factor,prec_matrix)) << " 0 0 cm}%\n";
+  //P.precision(2);
 
   std::map<int,layerrecord>::iterator lay_it = LAYERHASH.find(sheet_it->layer);
   if (lay_it == LAYERHASH.end()) therror (("This can't happen!"));
@@ -1142,7 +1152,7 @@ void print_navigator(std::ofstream& P, std::list<sheetrecord>::iterator sheet_it
                       LAYOUT.hoffset; 
                 yc -= LAYOUT.vsize * (sheet_it->namey - LAYOUT.nav_up) + 
                       LAYOUT.voffset; 
-                P << "\\PB{" << xc << "}{" << yc << "}{" <<
+                P << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                         tex_get_ref(tex_Xname("I"+(K->name))) << "}%" << std::endl;
                 NAV_SCRAPS.insert(K->name);
               }
@@ -1172,7 +1182,7 @@ void print_navigator(std::ofstream& P, std::list<sheetrecord>::iterator sheet_it
                   LAYOUT.hoffset; 
             yc -= LAYOUT.vsize * (sheet_it->namey - LAYOUT.nav_up) + 
                   LAYOUT.voffset; 
-            P << "\\PB{" << xc << "}{" << yc << "}{" <<
+            P << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                     tex_get_ref(tex_Xname("I"+(K->name))) << "}%" << std::endl;
             NAV_SCRAPS.insert(K->name);
           }
@@ -1203,7 +1213,7 @@ void print_navigator(std::ofstream& P, std::list<sheetrecord>::iterator sheet_it
                       LAYOUT.hoffset; 
                 yc -= LAYOUT.vsize * (sheet_it->namey - LAYOUT.nav_up) + 
                       LAYOUT.voffset; 
-                P << "\\PB{" << xc << "}{" << yc << "}{" <<
+                P << "\\PB{" << fmt::format("{}",thdouble(xc,prec_xy)) << "}{" << fmt::format("{}",thdouble(yc,prec_xy)) << "}{" <<
                         tex_get_ref(tex_Xname("B"+(K->name))) << "}%" << std::endl;
                 NAV_SCRAPS.insert(K->name);
               }
@@ -1216,16 +1226,18 @@ void print_navigator(std::ofstream& P, std::list<sheetrecord>::iterator sheet_it
 
   // navigator grid
   P << "\\PL{Q}" << "\\PL{q " << black2pdf(1, fillstroke::stroke) << " 0 0 " <<
-       HSN << " " << VSN << " re S 0.1 w}";
+       fmt::format("{}",thdouble(HSN,prec_xy)) << " " << fmt::format("{}",thdouble(VSN,prec_xy)) << " re S 0.1 w}";
   for (int i = 1; i < nav_x; i++)      
-    P << "\\PL{" << HSN*i/nav_x << " 0 m " << HSN*i/nav_x << " " << VSN << " l S}%\n";
+    P << "\\PL{" << fmt::format("{}",thdouble(HSN*i/nav_x,prec_xy)) << " 0 m " << fmt::format("{}",thdouble(HSN*i/nav_x,prec_xy)) << " " <<
+         fmt::format("{}",thdouble(VSN,prec_xy)) << " l S}%\n";
   for (int i = 1; i < nav_y; i++)
-    P << "\\PL{0 " << VSN*i/nav_y << " m " << HSN << " " << VSN*i/nav_y << " l S}%\n";
+    P << "\\PL{0 " << fmt::format("{}",thdouble(VSN*i/nav_y,prec_xy)) << " m " << fmt::format("{}",thdouble(HSN,prec_xy)) << " " <<
+         fmt::format("{}",thdouble(VSN*i/nav_y,prec_xy)) << " l S}%\n";
   P << "\\PL{0.4 w " <<
-    HSN*LAYOUT.nav_right/nav_x << " " << VSN*LAYOUT.nav_up/nav_y << " " <<
-    HSN/nav_x << " " << VSN/nav_y << " " << " re S Q}";
+    fmt::format("{}",thdouble(HSN*LAYOUT.nav_right/nav_x,prec_xy)) << " " << fmt::format("{}",thdouble(VSN*LAYOUT.nav_up/nav_y,prec_xy)) << " " <<
+    fmt::format("{}",thdouble(HSN/nav_x,prec_xy)) << " " << fmt::format("{}",thdouble(VSN/nav_y,prec_xy)) << " " << " re S Q}";
   // XObject definition
-  P << "\\hfill}\\ht\\xxx=" << VSN << "bp\\dp\\xxx=0bp\n";
+  P << "\\hfill}\\ht\\xxx=" << fmt::format("{}",thdouble(VSN,prec_xy)) << "bp\\dp\\xxx=0bp\n";
   P << "\\immediate\\pdfxform";
   if (icc_used())  P << " resources{/ColorSpace <<" << icc2pdfresources() << ">>} ";
   P << "\\xxx\\newcount\\" <<
@@ -1242,12 +1254,14 @@ void print_margins(std::ofstream& PAGEDEF) {
     double j = LAYOUT.vsize + LAYOUT.overlap;
     PAGEDEF << "\\PL{" << black2pdf(1, fillstroke::stroke) << "}";
     PAGEDEF << "\\PL{0.5 w}";
-    PAGEDEF << "\\PL{0 " << LAYOUT.overlap << " m " << HS << " " << 
-                            LAYOUT.overlap << " l S}";
-    PAGEDEF << "\\PL{0 " << j << " m " << HS << " " << j << " l S}";
-    PAGEDEF << "\\PL{" << LAYOUT.overlap << " 0 m " << LAYOUT.overlap << 
-               " " << VS << " l S}";
-    PAGEDEF << "\\PL{" << i << " 0 m " << i << " " << VS << " l S}";
+    PAGEDEF << "\\PL{0 " << fmt::format("{}",thdouble(LAYOUT.overlap,prec_xy)) << " m " << fmt::format("{}",thdouble(HS,prec_xy)) << " " <<
+                            fmt::format("{}",thdouble(LAYOUT.overlap,prec_xy)) << " l S}";
+    PAGEDEF << "\\PL{0 " << fmt::format("{}",thdouble(j,prec_xy)) << " m " << fmt::format("{}",thdouble(HS,prec_xy)) << " "
+                         << fmt::format("{}",thdouble(j,prec_xy)) << " l S}";
+    PAGEDEF << "\\PL{" << fmt::format("{}",thdouble(LAYOUT.overlap,prec_xy)) << " 0 m " << fmt::format("{}",thdouble(LAYOUT.overlap,prec_xy)) <<
+               " " << fmt::format("{}",thdouble(VS,prec_xy)) << " l S}";
+    PAGEDEF << "\\PL{" << fmt::format("{}",thdouble(i,prec_xy)) << " 0 m " << fmt::format("{}",thdouble(i,prec_xy)) << " " <<
+                          fmt::format("{}",thdouble(VS,prec_xy)) << " l S}";
   }
   PAGEDEF << "\\PL{Q}%" << std::endl;
 }
@@ -1494,20 +1508,20 @@ R"(\pdfcompresslevel=9%
     if (HS>14000 || VS>14000) 
       therror(("Map is too large for PDF format. Try smaller scale!"));
     PAGEDEF << "\\eject" << std::endl;
-    PAGEDEF << "\\hsize=" << HS << "bp" << std::endl;
-    PAGEDEF << "\\vsize=" << VS << "bp" << std::endl;
+    PAGEDEF << "\\hsize=" << fmt::format("{}",thdouble(HS,prec_xy)) << "bp" << std::endl;
+    PAGEDEF << "\\vsize=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp" << std::endl;
     PAGEDEF << "\\pdfpagewidth=\\hsize\\advance\\pdfpagewidth by " <<
-                                             2*LAYOUT.overlap << "bp" << std::endl;
+                                             fmt::format("{}",thdouble(2*LAYOUT.overlap,prec_xy)) << "bp" << std::endl;
     PAGEDEF << "\\pdfpageheight=\\vsize\\advance\\pdfpageheight by " <<
-                                             2*LAYOUT.overlap << "bp" << std::endl;
+                                             fmt::format("{}",thdouble(2*LAYOUT.overlap,prec_xy)) << "bp" << std::endl;
     PAGEDEF << "\\hoffset=0cm" << std::endl;
     PAGEDEF << "\\voffset=0cm" << std::endl;
-    PAGEDEF << "\\pdfhorigin=" << LAYOUT.overlap << "bp" << std::endl;
-    PAGEDEF << "\\pdfvorigin=" << LAYOUT.overlap << "bp" << std::endl;
+    PAGEDEF << "\\pdfhorigin=" << fmt::format("{}",thdouble(LAYOUT.overlap,prec_xy)) << "bp" << std::endl;
+    PAGEDEF << "\\pdfvorigin=" << fmt::format("{}",thdouble(LAYOUT.overlap,prec_xy)) << "bp" << std::endl;
   }
   
   if (mode == ATLAS) {
-    PAGEDEF << "\\newdimen\\overlap\\overlap=" << LAYOUT.overlap << "bp" << std::endl;
+    PAGEDEF << "\\newdimen\\overlap\\overlap=" << fmt::format("{}",thdouble(LAYOUT.overlap,prec_xy)) << "bp" << std::endl;
     for (std::list<sheetrecord>::iterator I = SHEET.begin(); 
                                      I != SHEET.end(); I++) {
 
@@ -1516,12 +1530,12 @@ R"(\pdfcompresslevel=9%
 
 // cout << "*" << flush; 
 
-      PAGEDEF << "\\setbox\\xxx=\\hbox to "<< HS << "bp{%" << std::endl;
+      PAGEDEF << "\\setbox\\xxx=\\hbox to "<< fmt::format("{}",thdouble(HS,prec_xy)) << "bp{%" << std::endl;
 
       print_map(I->layer, PAGEDEF, I);
       print_margins(PAGEDEF);
 
-      PAGEDEF << "\\hfill}\\ht\\xxx=" << VS << "bp\\dp\\xxx=0bp" << std::endl;
+      PAGEDEF << "\\hfill}\\ht\\xxx=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp\\dp\\xxx=0bp" << std::endl;
       PAGEDEF << "\\immediate\\pdfxform";
       if (icc_used())  PAGEDEF << " resources{/ColorSpace <<" << icc2pdfresources() << ">>} ";
       PAGEDEF << "\\xxx\\newcount\\" << tex_Sname(u2str(I->id)) <<
@@ -1536,8 +1550,8 @@ R"(\pdfcompresslevel=9%
     }
   }
   else {
-    PAGEDEF << "\\newdimen\\x \\x=" << HS << "bp" << std::endl;
-    PAGEDEF << "\\newdimen\\y \\y=" << VS << "bp" << std::endl;
+    PAGEDEF << "\\newdimen\\x \\x=" << fmt::format("{}",thdouble(HS,prec_xy)) << "bp" << std::endl;
+    PAGEDEF << "\\newdimen\\y \\y=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp" << std::endl;
     PAGEDEF << "\\setbox\\xxx=\\hbox to \\x{\\maplayout\\hfill}%\\dp\\xxx=0bp" << std::endl;
     PAGEDEF << "\\advance\\x by \\extraE" << std::endl;
     PAGEDEF << "\\advance\\x by \\extraW" << std::endl;
@@ -1558,7 +1572,7 @@ R"(\pdfcompresslevel=9%
     PAGEDEF << "\\advance\\pdfpageheight by \\extraN" << std::endl;
     PAGEDEF << "\\advance\\pdfpageheight by \\extraS" << std::endl;
 
-    PAGEDEF << "\\newdimen\\overlap\\overlap=" << LAYOUT.overlap << "bp" << std::endl;
+    PAGEDEF << "\\newdimen\\overlap\\overlap=" << fmt::format("{}",thdouble(LAYOUT.overlap,prec_xy)) << "bp" << std::endl;
 
     PAGEDEF << "\\dimtobp{\\the\\pdfpagewidth}\\edef\\xsize{\\tmpdef}%" << std::endl;
     PAGEDEF << "\\dimtobp{\\the\\pdfpageheight}\\edef\\ysize{\\tmpdef}%" << std::endl;
@@ -1579,30 +1593,31 @@ R"(\pdfcompresslevel=9%
     PAGEDEF << "\\dimtobp{\\framey}\\edef\\Framey{\\tmpdef}%" << std::endl;
 
 
-    PAGEDEF << "\\adjustedHS=" << HS << "bp" <<
+    PAGEDEF << "\\adjustedHS=" << fmt::format("{}",thdouble(HS,prec_xy)) << "bp" <<
       "\\advance\\adjustedHS by \\extraE" << 
       "\\advance\\adjustedHS by \\extraW" <<
       "\\advance\\adjustedHS by \\overlap" << 
       "\\advance\\adjustedHS by \\overlap" <<  std::endl;
 
-    PAGEDEF << "\\adjustedVS=" << VS << "bp" << 
+    PAGEDEF << "\\adjustedVS=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp" <<
       "\\advance\\adjustedVS by \\extraN" << 
       "\\advance\\adjustedVS by \\extraS" << 
       "\\advance\\adjustedVS by \\overlap" << 
       "\\advance\\adjustedVS by \\overlap" << std::endl;
 
     //calibration
-    PAGEDEF.precision(10);
+    //PAGEDEF.precision(10);
     for (int i=0; i<9; i++) {
-      PAGEDEF << "\\calibrX{" << LAYOUT.calibration_local[i].x - MINX << "bp}\\tmpdimenX=\\tmpdimen" << std::endl;
-      PAGEDEF << "\\calibrY{" << LAYOUT.calibration_local[i].y - MINY << "bp}\\tmpdimenY=\\tmpdimen" << std::endl;
+      PAGEDEF << "\\calibrX{" << fmt::format("{}",thdouble(LAYOUT.calibration_local[i].x - MINX,10)) << "bp}\\tmpdimenX=\\tmpdimen" << std::endl;
+      PAGEDEF << "\\calibrY{" << fmt::format("{}",thdouble(LAYOUT.calibration_local[i].y - MINY,10)) << "bp}\\tmpdimenY=\\tmpdimen" << std::endl;
     
       PAGEDEF << "\\pdfcatalog { /thCalibrate" << i << 
-                 " (X=\\the\\tmpdimenX, Y=\\the\\tmpdimenY, L=" << LAYOUT.calibration_latlong[i].x << 
-                 ", F=" << LAYOUT.calibration_latlong[i].y << ")}" << std::endl;
+                 " (X=\\the\\tmpdimenX, Y=\\the\\tmpdimenY, L=" << fmt::format("{}",thdouble(LAYOUT.calibration_latlong[i].x,10)) <<
+                 ", F=" << fmt::format("{}",thdouble(LAYOUT.calibration_latlong[i].y,10)) << ")}" << std::endl;
     }
-    PAGEDEF << "\\pdfcatalog { /thCalibrate (HS=\\the\\adjustedHS, VS=\\the\\adjustedVS, HD=" << LAYOUT.calibration_hdist << ")}";
-    PAGEDEF.precision(2);
+    PAGEDEF << "\\pdfcatalog { /thCalibrate (HS=\\the\\adjustedHS, VS=\\the\\adjustedVS, HD=" <<
+               fmt::format("{}",thdouble(LAYOUT.calibration_hdist,10)) << ")}";
+    //PAGEDEF.precision(2);
 
     PAGEDEF << "\\tmpdimen=\\extraW\\advance\\tmpdimen by \\overlap" << std::endl;
     PAGEDEF << "\\dimtobp{\\tmpdimen}\\edef\\adjustedX{\\tmpdef}%" << std::endl;
@@ -1648,13 +1663,13 @@ R"(\pdfcompresslevel=9%
     for (std::map<int,layerrecord>::iterator I = LAYERHASH.begin();
                                         I != LAYERHASH.end(); I++) {
       if (I->second.Z == 0) {
-        PAGEDEF << "\\setbox\\xxx=\\hbox to " << HS << "bp{%" << std::endl;
+        PAGEDEF << "\\setbox\\xxx=\\hbox to " << fmt::format("{}",thdouble(HS,prec_xy)) << "bp{%" << std::endl;
                             // we need flush layer data using XObject 
                             // (the text clipping path may become too large)
 
         print_map((*I).first,PAGEDEF);
 
-        PAGEDEF << "\\hfill}\\ht\\xxx=" << VS << "bp\\dp\\xxx=0bp" << std::endl;
+        PAGEDEF << "\\hfill}\\ht\\xxx=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp\\dp\\xxx=0bp" << std::endl;
         PAGEDEF << "\\immediate\\pdfxform ";
         if (LAYOUT.OCG) {
           PAGEDEF << "attr{/OC \\the\\oc" << u2str(I->first) << "\\space 0 R} ";
@@ -1670,26 +1685,28 @@ R"(\pdfcompresslevel=9%
 
     if (LAYOUT.map_grid) {
       PAGEDEF << "\\PL{q .4 w " << black2pdf(0.4, fillstroke::fillstroke) << " }%" << std::endl;
-      PAGEDEF << "\\PL{0 0 " << HS << " " << VS << " re S}%" << std::endl;
+      PAGEDEF << "\\PL{0 0 " << fmt::format("{}",thdouble(HS,prec_xy)) << " " << fmt::format("{}",thdouble(VS,prec_xy)) << " re S}%" << std::endl;
       for (double i=0; i <= HS; i += LAYOUT.hsize) {
-        PAGEDEF << "\\PL{" << i << " 0 m " << i << " " << VS << " l S}%" << std::endl;
+        PAGEDEF << "\\PL{" << fmt::format("{}",thdouble(i,prec_xy)) << " 0 m " << fmt::format("{}",thdouble(i,prec_xy)) << " " <<
+                   fmt::format("{}",thdouble(VS,prec_xy)) << " l S}%" << std::endl;
 	if (i<HS) {
-          PAGEDEF << "\\PL{q 1 0 0 1 " << i+LAYOUT.hsize/2 << 
-	    " 0 cm}\\gridcoord{8}{\\size[24]" << grid_name(LAYOUT.labelx,round((MINX+i)/LAYOUT.hsize)) << 
+          PAGEDEF << "\\PL{q 1 0 0 1 " << fmt::format("{}",thdouble(i+LAYOUT.hsize/2,prec_xy)) <<
+	    " 0 cm}\\gridcoord{8}{\\size[24]" << grid_name(LAYOUT.labelx,round((MINX+i)/LAYOUT.hsize)) <<
 	    "}\\PL{Q}%" << std::endl;
-          PAGEDEF << "\\PL{q 1 0 0 1 " << i+LAYOUT.hsize/2 << " " << VS <<
-	    " cm}\\gridcoord{2}{\\size[24]" << grid_name(LAYOUT.labelx,round((MINX+i)/LAYOUT.hsize)) << 
+          PAGEDEF << "\\PL{q 1 0 0 1 " << fmt::format("{}",thdouble(i+LAYOUT.hsize/2,prec_xy)) << " " << fmt::format("{}",thdouble(VS,prec_xy)) <<
+	    " cm}\\gridcoord{2}{\\size[24]" << grid_name(LAYOUT.labelx,round((MINX+i)/LAYOUT.hsize)) <<
 	    "}\\PL{Q}%" << std::endl;
 	}
       }
       for (double i=0; i <= VS; i += LAYOUT.vsize) {
-        PAGEDEF << "\\PL{0 " << i << " m " << HS << " " << i << " l S}%" << std::endl;
+        PAGEDEF << "\\PL{0 " << fmt::format("{}",thdouble(i,prec_xy)) << " m " << fmt::format("{}",thdouble(HS,prec_xy)) << " " <<
+                   fmt::format("{}",thdouble(i,prec_xy)) << " l S}%" << std::endl;
 	if (i<VS) {
-          PAGEDEF << "\\PL{q 1 0 0 1 0 " << i+LAYOUT.vsize/2 << 
-    	    " cm}\\gridcoord{6}{\\size[24]" << grid_name(LAYOUT.labely,round((MINY+VS-i)/LAYOUT.vsize)-1) << 
+          PAGEDEF << "\\PL{q 1 0 0 1 0 " << fmt::format("{}",thdouble(i+LAYOUT.vsize/2,prec_xy)) <<
+    	    " cm}\\gridcoord{6}{\\size[24]" << grid_name(LAYOUT.labely,round((MINY+VS-i)/LAYOUT.vsize)-1) <<
 	    "}\\PL{Q}%" << std::endl;
-          PAGEDEF << "\\PL{q 1 0 0 1 " << HS << " " << i+LAYOUT.vsize/2 << 
-	    " cm}\\gridcoord{4}{\\size[24]" << grid_name(LAYOUT.labely,round((MINY+VS-i)/LAYOUT.vsize)-1) << 
+          PAGEDEF << "\\PL{q 1 0 0 1 " << fmt::format("{}",thdouble(HS,prec_xy)) << " " << fmt::format("{}",thdouble(i+LAYOUT.vsize/2,prec_xy)) <<
+	    " cm}\\gridcoord{4}{\\size[24]" << grid_name(LAYOUT.labely,round((MINY+VS-i)/LAYOUT.vsize)-1) <<
 	    "}\\PL{Q}%" << std::endl;
 	}
       }
@@ -1699,7 +1716,7 @@ R"(\pdfcompresslevel=9%
 ////    PAGEDEF << "\\maplayout\\hfill}\\ht\\xxx=" << VS << "bp\\dp\\xxx=0bp" << std::endl;
 ////    PAGEDEF << "\\immediate\\pdfxform\\xxx\\PB{0}{0}{\\pdflastxform}%" << std::endl;
 
-    PAGEDEF << "\\hfill}\\ht\\xxx=" << VS << "bp\\dp\\xxx=0bp" << std::endl;
+    PAGEDEF << "\\hfill}\\ht\\xxx=" << fmt::format("{}",thdouble(VS,prec_xy)) << "bp\\dp\\xxx=0bp" << std::endl;
 //    PAGEDEF << "\\immediate\\pdfxform\\xxx\\PB{0}{0}{\\pdflastxform}%" << std::endl;
     PAGEDEF << "\\box\\xxx%" << std::endl;
     
